@@ -1,8 +1,7 @@
 """List plugins"""
+from __future__ import annotations
+from typing import TYPE_CHECKING, Any, Iterable, List, Tuple
 
-from typing import Any, Iterable, List, Mapping, Tuple
-
-from pyparam import Params
 from rich import print
 
 from ._hooks import CLIPlugin
@@ -13,6 +12,10 @@ from ..defaults import (
 )
 from ..utils import load_entrypoints
 
+if TYPE_CHECKING:
+    from argx import ArgumentParser
+    from argparse import Namespace
+
 
 COMMAND = "plugins"
 GROUPS = [
@@ -55,7 +58,8 @@ def _list_group_plugins(
         plugins: A list of tuples with name and plugin
     """
     print("")
-    print(f"{GROUP_NAMES[group]} plugins:")
+    print(f"[bold][u]{GROUP_NAMES[group]} plugins:[/u][/bold]")
+    namelen = max(len(name) for name, _ in plugins) if plugins else 0
     for name, plugin in plugins:
         try:
             ver = plugin.version
@@ -64,7 +68,7 @@ def _list_group_plugins(
                 ver = plugin.__version__
             except AttributeError:
                 ver = "unknown"
-        print(f"- {name}: (version: {ver})")
+        print(f"- {name.ljust(namelen)}: (version: {ver})")
 
 
 def _list_plugins(plugins: List[Tuple[str, str, Any]]) -> None:
@@ -102,27 +106,28 @@ class CliPluginsPlugin(CLIPlugin):
 
     name = "plugins"
 
-    @property
-    def params(self) -> Params:
-        """Define the params"""
-        pms = Params(desc=self.__class__.__doc__, help_on_void=False)
-        pms.add_param(
-            "g,group",
-            default="",
-            desc="The name of the entry point group. "
-            "If not provided, show all plugins. "
-            f"Avaiable groups are: {' '.join(GROUPS)}",
+    def __init__(
+        self,
+        parser: ArgumentParser,
+        subparser: ArgumentParser,
+    ) -> None:
+        super().__init__(parser, subparser)
+        subparser.add_argument(
+            "-g",
+            "--group",
+            choices=GROUPS + ["all"],
+            default="all",
+            help="The name of the entry point group. Show all if not provided",
         )
-        return pms
 
-    def exec_command(self, args: Mapping[str, Any]) -> None:
+    def exec_command(self, args: Namespace) -> None:
         """Execute the command"""
         from ..version import __version__
         print("Pipen version:", __version__)
 
         plugins: List[Tuple[str, str, Any]] = []
 
-        if args.group:
+        if args.group and args.group != "all":
             for name, plugin in _get_plugins_by_group(args.group):
                 plugins.append((args.group, name, plugin))
 
