@@ -4,13 +4,15 @@ from typing import ClassVar
 
 from diot import Diot
 from xqute import JobErrorStrategy
-from xqute import logger as xqute_logger
+from xqute.utils import logger as xqute_logger
 
-# turn xqute's logger off
-xqute_logger.setLevel(100)
-xqute_logger.removeHandler(xqute_logger.handlers[0])
+# Remove the rich handler
+_xqute_handlers = xqute_logger.handlers
+if _xqute_handlers:
+    # The very first handler is the rich handler
+    xqute_logger.removeHandler(_xqute_handlers[0])
 
-LOGGER_NAME = "main"
+LOGGER_NAME = "core"
 CONFIG_FILES = (
     Path("~/.pipen.toml").expanduser(),
     "./.pipen.toml",
