@@ -36,12 +36,11 @@ Or add a process at runtime:
 from __future__ import annotations
 
 from os import PathLike
-from functools import wraps
-from typing import Callable, Type, List
+from functools import wraps, cached_property
+from typing import Any, Callable, Mapping, Type, List
 from abc import ABC, ABCMeta
 from diot import Diot
 
-from .utils import cached_property
 from .pipen import Pipen
 from .proc import Proc
 
@@ -73,6 +72,7 @@ class ProcGroup(ABC, metaclass=ProcGropuMeta):
     """
 
     name: str | None = None
+    __meta__: Mapping[str, Any] = {}
     DEFAULTS = Diot()
     PRESERVED = {
         "opts",
@@ -86,6 +86,10 @@ class ProcGroup(ABC, metaclass=ProcGropuMeta):
         "_INST",
     }
 
+    def __init_subclass__(cls) -> None:
+        # Clear the meta
+        cls.__meta__ = {}
+
     def __init__(self, **opts) -> None:
         self.opts = Diot(self.__class__.DEFAULTS or {}) | (opts or {})
         self.name = self.__class__.name or self.__class__.__name__
@@ -100,6 +104,8 @@ class ProcGroup(ABC, metaclass=ProcGropuMeta):
         for name, attr in self.__class__.__dict__.items():
             if isinstance(attr, cached_property):
                 getattr(self, name)
+            elif isinstance(attr, type) and issubclass(attr, Proc):
+                self.add_proc(attr)
 
     def add_proc(
         self_or_method: ProcGroup | Callable[[ProcGroup], Type[Proc]],
@@ -130,8 +136,8 @@ class ProcGroup(ABC, metaclass=ProcGropuMeta):
                 )
 
             setattr(self_or_method, proc.name, proc)
-            proc.__procgroup__ = self_or_method
-            if not proc.requires:
+            proc.__meta__["procgroup"] = self_or_method  # type: ignore
+            if not proc.requires and proc not in self_or_method.starts:
                 self_or_method.starts.append(proc)
             self_or_method.procs[proc.name] = proc
             return proc
@@ -143,17 +149,11 @@ class ProcGroup(ABC, metaclass=ProcGropuMeta):
             if proc is None:
                 return None
 
-            if (
-                not isinstance(proc, Proc)
-                and (not isinstance(proc, type) or not issubclass(proc, Proc))
-            ):
-                raise ValueError(
-                    f"`{proc}` is not a process "
-                    "(either a subclass or an instance of Proc)"
-                )
+            if (not isinstance(proc, type) or not issubclass(proc, Proc)):
+                raise ValueError(f"`{proc}` is not a Proc subclass")
 
-            proc.__procgroup__ = self
-            if not proc.requires:
+            proc.__meta__["procgroup"] = self
+            if not proc.requires and proc not in self.starts:
                 self.starts.append(proc)
             self.procs[proc.name] = proc
             return proc
